pub struct PollHandler<R: PollRead, A: PollAccept<R>> { /* private fields */ }
A wrapper struct to that will use a designated thread to handle TransmittingSvcAcceptor or TransmittingSvcAcceptorRef events and resulting respective CltRecver & CltRecverRef instances

Implementations

source

impl<R: PollRead, A: PollAccept<R>> PollHandler<R, A>

source

pub fn with_events_capacity(capacity: usize) -> Self

Create a new PollHandler with a given capacity of Events on a single poll call

source

pub fn add_acceptor(&mut self, acceptor: A)

Add a TransmittingSvcAcceptor or TransmittingSvcAcceptorRef to the PollHandler to be polled for incoming connections. All resulting connections in the form of CltRecver will also be serviced by this PollHandler instance.

source

pub fn add_recver(&mut self, recver: R)

source

pub fn into_spawned_handler(self, name: &str) -> SpawnedPollHandler<R, A>

Spawns a new thread with a given name that will continuously poll for events of TransmittingSvcAcceptor or TransmittingSvcAcceptorRef and resulting CltRecvers instances