ProtocolSessionState

Struct ProtocolSessionState 

pub struct ProtocolSessionState<T>(/* private fields */);
This facility helps user capture and maintain protocol state across a single connection. Unlike ProtocolConnectionState this facility designed to works across a session which spans across multiple connected/disconnected connections

Use cases

Key features

  • Each new connection to crate::prelude::Svc will have access to any state captured by prior or still active connections on the same crate::prelude::Svc port. This is achieved by using Clone implementation of Arc’s container for T.

Implementations

Source

impl<T> ProtocolSessionState<T>

pub fn new(state: T) -> Self

pub fn set(&self, state: T)

pub fn lock(&self) -> MutexGuard<'_, T>