pub struct ProtocolSessionState<T>(/* private fields */);Expand description
This facility helps user capture and maintain protocol state across a single connection. Unlike ProtocolConnectionState this facility designed to works across a session which spans across multiple connected/disconnected connections
Use cases
- Use this to maintain a log of messages sent and received
- Use this to recover crate::prelude::Clt state after reconnect to crate::prelude::Svc since crate::prelude::Svc will have access to all of the activity across all connections.
Key features
- Each new connection to crate::prelude::Svc will have access to any state captured by prior or still active connections
on the same crate::prelude::Svc port. This is achieved by using Clone implementation of Arc’s container for
T.
Implementations
Sourceimpl<T> ProtocolSessionState<T>
impl<T> ProtocolSessionState<T>